@@ -2,10 +2,10 @@ package Dist::Zilla::Plugin::Author::Plicease::TransformTravis;
 
 use Moose;
 with 'Dist::Zilla::Role::FileGatherer';
-use YAML::XS qw( Dump LoadFile );
+use YAML qw( Dump LoadFile );
 
 # ABSTRACT: transform .travis.yml so that it uses Module::Build or MakeMaker for deps
-our $VERSION = '1.53'; # VERSION
+our $VERSION = '1.54'; # VERSION
 
 
 use namespace::autoclean;
@@ -57,7 +57,7 @@ Dist::Zilla::Plugin::Author::Plicease::TransformTravis - transform .travis.yml s
 
 =head1 VERSION
 
-version 1.53
+version 1.54
 
 =head1 SYNOPSIS
 
